@@ -19,6 +19,7 @@
     GyMMM => "MMM y. G",
     GyMMMEd => "E, d. MMM y. G",
     GyMMMd => "d. MMM y. G",
+    GyMd => "GGGGG y-MM-dd",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -127,7 +128,7 @@
   ],
   era_narrow => [
     "p.n.e.",
-    "n.e.",
+    "n. e.",
   ],
   era_wide => [
     "prije nove ere",
@@ -273,5 +274,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 37,
+  version => 41,
 }
