@@ -17,18 +17,19 @@
     Ehms => "E h:mm:ss a",
     Gy => "y G",
     GyMMM => "LLL y G",
-    GyMMMEd => "E, d MMM y G",
+    GyMMMEd => "E d MMM y G",
     GyMMMd => "d MMM y G",
+    GyMd => "d/M/y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "E, d/M",
+    MEd => "E d/M",
     MMM => "MMM",
-    MMMEd => "E, d MMM",
-    MMMMEd => "E, d MMMM",
+    MMMEd => "E d MMM",
+    MMMMEd => "E d MMMM",
     "MMMMW-count-one" => "\N{U+03b5}\N{U+03b2}\N{U+03b4}\N{U+03bf}\N{U+03bc}\N{U+03ac}\N{U+03b4}\N{U+03b1} W \N{U+03c4}\N{U+03bf}\N{U+03c5} MMMM",
     "MMMMW-count-other" => "\N{U+03b5}\N{U+03b2}\N{U+03b4}\N{U+03bf}\N{U+03bc}\N{U+03ac}\N{U+03b4}\N{U+03b1} W \N{U+03c4}\N{U+03bf}\N{U+03c5} MMMM",
     MMMMd => "d MMMM",
@@ -43,19 +44,19 @@
     ms => "mm:ss",
     y => "y",
     yM => "M/y",
-    yMEd => "E, d/M/y",
+    yMEd => "E d/M/y",
     yMMM => "MMM y",
-    yMMMEd => "E, d MMM y",
+    yMMMEd => "E d MMM y",
     yMMMM => "LLLL y",
     yMMMd => "d MMM y",
     yMd => "d/M/y",
-    yQQQ => "y QQQ",
-    yQQQQ => "y QQQQ",
+    yQQQ => "QQQ y",
+    yQQQQ => "QQQQ y",
     "yw-count-one" => "\N{U+03b5}\N{U+03b2}\N{U+03b4}\N{U+03bf}\N{U+03bc}\N{U+03ac}\N{U+03b4}\N{U+03b1} w \N{U+03c4}\N{U+03bf}\N{U+03c5} Y",
     "yw-count-other" => "\N{U+03b5}\N{U+03b2}\N{U+03b4}\N{U+03bf}\N{U+03bc}\N{U+03ac}\N{U+03b4}\N{U+03b1} w \N{U+03c4}\N{U+03bf}\N{U+03c5} Y",
   },
   code => "el-CY",
-  date_format_full => "EEEE, d MMMM y",
+  date_format_full => "EEEE d MMMM y",
   date_format_long => "d MMMM y",
   date_format_medium => "d MMM y",
   date_format_short => "d/M/yy",
@@ -269,5 +270,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 39,
+  version => 41,
 }
