@@ -19,6 +19,7 @@
     GyMMM => "G y MMM",
     GyMMMEd => "G y MMM d, E",
     GyMMMd => "G y MMM d",
+    GyMd => "GGGGG y-MM-dd",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -127,11 +128,11 @@
     "pK",
   ],
   first_day_of_week => 1,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
-  glibc_date_format => "%m/%d/%y",
-  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
+  glibc_date_1_format => "%a %d %b %Y %T %z",
+  glibc_date_format => "%Y-%m-%d",
+  glibc_datetime_format => "%a %d %b %Y %T",
   glibc_time_12_format => "%I:%M:%S %p",
-  glibc_time_format => "%H:%M:%S",
+  glibc_time_format => "%T",
   language => "Esperanto",
   month_format_abbreviated => [
     "jan",
@@ -217,11 +218,11 @@
     "novembro",
     "decembro",
   ],
-  name => "Esperanto World",
+  name => "Esperanto world",
   native_language => "esperanto",
-  native_name => "esperanto 001",
+  native_name => "esperanto Mondo",
   native_script => undef,
-  native_territory => "001",
+  native_territory => "Mondo",
   native_variant => undef,
   quarter_format_abbreviated => [
     "Q1",
@@ -260,11 +261,11 @@
     "Q4",
   ],
   script => undef,
-  territory => "World",
+  territory => "world",
   time_format_full => "H-'a' 'horo' 'kaj' m:ss zzzz",
   time_format_long => "HH:mm:ss z",
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 33,
+  version => 41,
 }
