@@ -22,12 +22,13 @@
     GyMMMMEd => "E, d 'de' MMMM 'de' y G",
     GyMMMMd => "d 'de' MMMM 'de' y G",
     GyMMMd => "d 'de' MMM 'de' y G",
+    GyMd => "d/M/y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
-    Hmsv => "H:mm:ss v",
-    Hmsvvvv => "H:mm:ss (vvvv)",
-    Hmv => "H:mm v",
+    Hmsv => "HH:mm:ss v",
+    Hmsvvvv => "HH:mm:ss vvvv",
+    Hmv => "HH:mm v",
     M => "L",
     MEd => "E, d/M",
     MMM => "LLL",
@@ -53,12 +54,12 @@
     yM => "M/y",
     yMEd => "E d/M/y",
     yMM => "M/y",
-    yMMM => "MMM 'de' y",
-    yMMMEd => "E, d 'de' MMM 'de' y",
+    yMMM => "MMM y",
+    yMMMEd => "E, d MMM y",
     yMMMM => "MMMM 'de' y",
     yMMMMEd => "EEE, d 'de' MMMM 'de' y",
     yMMMMd => "d 'de' MMMM 'de' y",
-    yMMMd => "d 'de' MMM 'de' y",
+    yMMMd => "d MMM y",
     yMd => "d/M/y",
     yQQQ => "QQQ 'de' y",
     yQQQQ => "QQQQ 'de' y",
@@ -73,7 +74,7 @@
   datetime_format_full => "{1}, {0}",
   datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1} {0}",
-  datetime_format_short => "{1} {0}",
+  datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
     "lun",
     "mar",
@@ -102,13 +103,13 @@
     "domingo",
   ],
   day_stand_alone_abbreviated => [
-    "lun.",
-    "mar.",
-    "mi\N{U+00e9}.",
-    "jue.",
-    "vie.",
-    "s\N{U+00e1}b.",
-    "dom.",
+    "lun",
+    "mar",
+    "mi\N{U+00e9}",
+    "jue",
+    "vie",
+    "s\N{U+00e1}b",
+    "dom",
   ],
   day_stand_alone_narrow => [
     "L",
@@ -148,18 +149,18 @@
   glibc_time_format => "%T",
   language => "Spanish",
   month_format_abbreviated => [
-    "ene.",
-    "feb.",
-    "mar.",
-    "abr.",
-    "may.",
-    "jun.",
-    "jul.",
-    "ago.",
-    "sep.",
-    "oct.",
-    "nov.",
-    "dic.",
+    "ene",
+    "feb",
+    "mar",
+    "abr",
+    "may",
+    "jun",
+    "jul",
+    "ago",
+    "sept",
+    "oct",
+    "nov",
+    "dic",
   ],
   month_format_narrow => [
     "E",
@@ -190,18 +191,18 @@
     "diciembre",
   ],
   month_stand_alone_abbreviated => [
-    "ene.",
-    "feb.",
-    "mar.",
-    "abr.",
-    "may.",
-    "jun.",
-    "jul.",
-    "ago.",
-    "sep.",
-    "oct.",
-    "nov.",
-    "dic.",
+    "ene",
+    "feb",
+    "mar",
+    "abr",
+    "may",
+    "jun",
+    "jul",
+    "ago",
+    "sept",
+    "oct",
+    "nov",
+    "dic",
   ],
   month_stand_alone_narrow => [
     "E",
@@ -280,5 +281,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 39,
+  version => 41,
 }
