@@ -19,6 +19,7 @@
     GyMMM => "MMM y G",
     GyMMMEd => "E, d. MMMM y G",
     GyMMMd => "d. MMM y G",
+    GyMd => "d.MM.y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -83,13 +84,13 @@
     "P",
   ],
   day_format_wide => [
-    "esmasp\N{U+00e4}ev",
-    "teisip\N{U+00e4}ev",
-    "kolmap\N{U+00e4}ev",
-    "neljap\N{U+00e4}ev",
-    "reede",
-    "laup\N{U+00e4}ev",
-    "p\N{U+00fc}hap\N{U+00e4}ev",
+    "Esmasp\N{U+00e4}ev",
+    "Teisip\N{U+00e4}ev",
+    "Kolmap\N{U+00e4}ev",
+    "Neljap\N{U+00e4}ev",
+    "Reede",
+    "Laup\N{U+00e4}ev",
+    "P\N{U+00fc}hap\N{U+00e4}ev",
   ],
   day_stand_alone_abbreviated => [
     "E",
@@ -110,13 +111,13 @@
     "P",
   ],
   day_stand_alone_wide => [
-    "esmasp\N{U+00e4}ev",
-    "teisip\N{U+00e4}ev",
-    "kolmap\N{U+00e4}ev",
-    "neljap\N{U+00e4}ev",
-    "reede",
-    "laup\N{U+00e4}ev",
-    "p\N{U+00fc}hap\N{U+00e4}ev",
+    "Esmasp\N{U+00e4}ev",
+    "Teisip\N{U+00e4}ev",
+    "Kolmap\N{U+00e4}ev",
+    "Neljap\N{U+00e4}ev",
+    "Reede",
+    "Laup\N{U+00e4}ev",
+    "P\N{U+00fc}hap\N{U+00e4}ev",
   ],
   era_abbreviated => [
     "eKr",
@@ -131,9 +132,9 @@
     "p\N{U+00e4}rast Kristust",
   ],
   first_day_of_week => 1,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
+  glibc_date_1_format => "%a %d %b %Y %T %Z",
   glibc_date_format => "%d.%m.%Y",
-  glibc_datetime_format => "%a %d %b %Y %T %Z",
+  glibc_datetime_format => "%a %d %b %Y %T",
   glibc_time_12_format => "%I:%M:%S %p",
   glibc_time_format => "%T",
   language => "Estonian",
@@ -270,5 +271,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 35,
+  version => 41,
 }
