@@ -19,6 +19,7 @@
     GyMMM => "G y MMM",
     GyMMMEd => "G y MMM d, E",
     GyMMMd => "G y MMM d",
+    GyMd => "GGGGG y-MM-dd",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -131,11 +132,11 @@
     "\N{U+0c95}\N{U+0ccd}\N{U+0cb0}\N{U+0cbf}\N{U+0cb8}\N{U+0ccd}\N{U+0ca4} \N{U+0cb6}\N{U+0c95}",
   ],
   first_day_of_week => 7,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
-  glibc_date_format => "%A %d %b %Y",
-  glibc_datetime_format => "%A %d %b %Y %I:%M:%S %p %Z",
+  glibc_date_1_format => "%A %d %b %Y %I:%M:%S %p %Z",
+  glibc_date_format => "%-d/%-m/%y",
+  glibc_datetime_format => "%A %d %b %Y %I:%M:%S %p",
   glibc_time_12_format => "%I:%M:%S %p %Z",
-  glibc_time_format => "%I:%M:%S  %Z",
+  glibc_time_format => "%I:%M:%S %p %Z",
   language => "Kannada",
   month_format_abbreviated => [
     "\N{U+0c9c}\N{U+0ca8}\N{U+0cb5}\N{U+0cb0}\N{U+0cbf}",
@@ -270,5 +271,5 @@
   time_format_medium => "hh:mm:ss a",
   time_format_short => "hh:mm a",
   variant => undef,
-  version => 37,
+  version => 41,
 }
