@@ -21,6 +21,7 @@
     GyMMMMEd => "E, d MMMM y G",
     GyMMMMd => "d MMMM y G",
     GyMMMd => "dd-MM-y GGGGG",
+    GyMd => "dd-MM-y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -31,7 +32,8 @@
     MMM => "LLL",
     MMMEd => "E, dd-MM",
     MMMMEd => "E, d MMMM",
-    "MMMMW-count-other" => "'week' W 'of' MMMM",
+    "MMMMW-count-one" => "W. 'emna' MMMM",
+    "MMMMW-count-other" => "W. 'emna' MMMM",
     MMMMd => "d MMMM",
     MMMd => "dd-MM",
     Md => "dd-MM",
@@ -54,7 +56,8 @@
     yMd => "dd-MM-y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
-    "yw-count-other" => "'week' w 'of' Y",
+    "yw-count-one" => "w. 'dal' Y",
+    "yw-count-other" => "w. 'emna' 'dal' Y",
   },
   code => "rm",
   date_format_full => "EEEE, 'ils' d MMMM y",
@@ -271,5 +274,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 37,
+  version => 41,
 }
