@@ -19,6 +19,7 @@
     GyMMM => "MMM y G",
     GyMMMEd => "E, MMM d, y G",
     GyMMMd => "MMM d, y G",
+    GyMd => "M/d/y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -55,13 +56,13 @@
     "yw-count-other" => "'toddobaadka' w 'ee' Y",
   },
   code => "so-ET",
-  date_format_full => "EEEE, MMMM dd, y",
-  date_format_long => "dd MMMM y",
+  date_format_full => "EEEE, MMMM d, y",
+  date_format_long => "MMMM d, y",
   date_format_medium => "dd-MMM-y",
   date_format_short => "dd/MM/yy",
-  datetime_format_full => "{1} {0}",
-  datetime_format_long => "{1} {0}",
-  datetime_format_medium => "{1} {0}",
+  datetime_format_full => "{1} 'ee' {0}",
+  datetime_format_long => "{1} 'ee' {0}",
+  datetime_format_medium => "{1} 'ee' {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
     "Isn",
@@ -118,8 +119,8 @@
     "Axad",
   ],
   era_abbreviated => [
-    "CH",
-    "CD",
+    "BC",
+    "AD",
   ],
   era_narrow => [
     "B",
@@ -269,5 +270,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 39,
+  version => 41,
 }
