@@ -19,6 +19,7 @@
     GyMMM => "MMM y. G",
     GyMMMEd => "E, d. MMM y. G",
     GyMMMd => "d. MMM y. G",
+    GyMd => "d.MM.y. GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -61,9 +62,9 @@
     "yw-count-other" => "w. '\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+0443}' Y.",
   },
   code => "sr-Cyrl-BA",
-  date_format_full => "EEEE, dd. MMMM y.",
-  date_format_long => "dd. MMMM y.",
-  date_format_medium => "dd.MM.y.",
+  date_format_full => "EEEE, d. MMMM y.",
+  date_format_long => "d. MMMM y.",
+  date_format_medium => "d. M. y.",
   date_format_short => "d.M.yy.",
   datetime_format_full => "{1} {0}",
   datetime_format_long => "{1} {0}",
@@ -233,10 +234,10 @@
   native_territory => "\N{U+0411}\N{U+043e}\N{U+0441}\N{U+043d}\N{U+0430} \N{U+0438} \N{U+0425}\N{U+0435}\N{U+0440}\N{U+0446}\N{U+0435}\N{U+0433}\N{U+043e}\N{U+0432}\N{U+0438}\N{U+043d}\N{U+0430}",
   native_variant => undef,
   quarter_format_abbreviated => [
-    "\N{U+041a}1",
-    "\N{U+041a}2",
-    "\N{U+041a}3",
-    "\N{U+041a}4",
+    "1. \N{U+043a}\N{U+0432}.",
+    "2. \N{U+043a}\N{U+0432}.",
+    "3. \N{U+043a}\N{U+0432}.",
+    "4. \N{U+043a}\N{U+0432}.",
   ],
   quarter_format_narrow => [
     "1.",
@@ -251,10 +252,10 @@
     "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+0440}\N{U+0442}\N{U+0438} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
   ],
   quarter_stand_alone_abbreviated => [
-    "\N{U+041a}1",
-    "\N{U+041a}2",
-    "\N{U+041a}3",
-    "\N{U+041a}4",
+    "1. \N{U+043a}\N{U+0432}.",
+    "2. \N{U+043a}\N{U+0432}.",
+    "3. \N{U+043a}\N{U+0432}.",
+    "4. \N{U+043a}\N{U+0432}.",
   ],
   quarter_stand_alone_narrow => [
     "1.",
@@ -275,5 +276,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 39,
+  version => 41,
 }
