@@ -16,9 +16,10 @@
     Ehm => "E h:mm a",
     Ehms => "E h:mm:ss a",
     Gy => "y G",
-    GyMMM => "LLL y G",
-    GyMMMEd => "E, d MMM y G",
-    GyMMMd => "d MMM y G",
+    GyMMM => "LLL y '\N{U+0440}'. G",
+    GyMMMEd => "E, d MMM y '\N{U+0440}'. G",
+    GyMMMd => "d MMM y '\N{U+0440}'. G",
+    GyMd => "dd-MM-y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -46,10 +47,10 @@
     y => "y",
     yM => "MM.y",
     yMEd => "E, dd.MM.y",
-    yMMM => "LLL y",
-    yMMMEd => "E, d MMM y",
-    yMMMM => "LLLL y",
-    yMMMd => "d MMM y",
+    yMMM => "LLL y '\N{U+0440}'.",
+    yMMMEd => "E, d MMM y '\N{U+0440}'.",
+    yMMMM => "LLLL y '\N{U+0440}'.",
+    yMMMd => "d MMM y '\N{U+0440}'.",
     yMd => "dd.MM.y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y '\N{U+0440}'.",
@@ -273,5 +274,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 39,
+  version => 41,
 }
