@@ -19,6 +19,7 @@
     GyMMM => "Gy\N{U+5e74}M\N{U+6708}",
     GyMMMEd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}E",
     GyMMMd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
+    GyMd => "GGGGG y-MM-dd",
     H => "H\N{U+65f6}",
     HHmm => "HH:mm",
     Hm => "HH:mm",
@@ -44,6 +45,7 @@
     ms => "mm:ss",
     y => "y\N{U+5e74}",
     yM => "M/y",
+    yMEEEEd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}EEEE",
     yMEd => "d/M/y\N{U+ff08}E\N{U+ff09}",
     yMM => "MM/y",
     yMMM => "y\N{U+5e74}M\N{U+6708}",
@@ -60,9 +62,9 @@
   date_format_long => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
   date_format_medium => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
   date_format_short => "d/M/yy",
-  datetime_format_full => "{1}{0}",
+  datetime_format_full => "{1} {0}",
   datetime_format_long => "{1} {0}",
-  datetime_format_medium => "{1}{0}",
+  datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
     "\N{U+5468}\N{U+4e00}",
@@ -270,5 +272,5 @@
   time_format_medium => "ah:mm:ss",
   time_format_short => "ah:mm",
   variant => undef,
-  version => 38,
+  version => 41,
 }
