@@ -8,6 +8,7 @@ use warnings;
 use feature qw( postderef signatures );
 use namespace::autoclean;
 
+use Carp qw( confess );
 use DateTime::Locale::Util qw( parse_locale_code );
 use JSON::MaybeXS qw( decode_json );
 use Specio::Declare;
@@ -27,11 +28,18 @@ has code => (
     required => 1,
 );
 
-has _source_data_root => (
+has _glibc_root => (
     is       => 'ro',
     isa      => t('Dir'),
     required => 1,
-    init_arg => 'source_data_root',
+    init_arg => 'glibc_root',
+);
+
+has _cldr_root => (
+    is       => 'ro',
+    isa      => t('Dir'),
+    required => 1,
+    init_arg => 'cldr_root',
 );
 
 has _parent_code => (
@@ -172,11 +180,21 @@ sub source_files ($self) {
     return grep {-f} $self->_json_file, $self->_glibc_file;
 }
 
-sub _build_cldr_json_data($self) {
+sub _build_cldr_json_data ($self) {
     my $json = $self->_json_from( $self->_json_file );
 
     my $json_file_id = $self->_json_file->parent->basename;
-    return $json->{main}{$json_file_id};
+    my $cldr         = $json->{main}{$json_file_id};
+
+    # https://unicode-org.atlassian.net/browse/CLDR-14361
+    if (   $self->code =~ /^sd-Deva/
+        && $cldr->{dates}{calendars}{gregorian}{quarters}{format}{narrow}{4}
+        == 1 ) {
+
+        $cldr->{dates}{calendars}{gregorian}{quarters}{format}{narrow}{4} = 4;
+    }
+
+    return $cldr;
 }
 
 sub _build_data_hash ($self) {
@@ -247,6 +265,10 @@ sub _build_glibc_data ($self) {
     my $parent = $self->_parent_locale;
 
     unless ( -f $self->_glibc_file ) {
+        confess sprintf(
+            'No glibc data for %s and it has no parent',
+            $self->code
+        ) unless $parent;
         return $parent->_glibc_data;
     }
 
@@ -276,9 +298,9 @@ sub _build_glibc_file ($self) {
     }
 
     # This ensures some sort of sanish fallback
-    $glibc_code = 'POSIX' if $self->code eq 'root';
+    $glibc_code = 'POSIX' if $self->code eq 'und';
 
-    return $self->_source_data_root->child( 'glibc-locales', $glibc_code );
+    return $self->_glibc_root->child($glibc_code);
 }
 
 sub _extract_glibc_value ( $self, $key, $raw ) {
@@ -303,7 +325,7 @@ sub _build_json_file ($self) {
 
     my $parent_file = $self->_gregorian_file_for_code( $self->_parent_code );
     unless ( -f $parent_file ) {
-        die "Could not find $code_file or $parent_file for locale ",
+        confess "Could not find $code_file or $parent_file for locale ",
             $self->code, "\n";
     }
 
@@ -317,9 +339,9 @@ sub _build_parent_code ($self) {
         return $code if -f $parent_file;
     }
 
-    # This is impossible because we should always be able to find root as a
+    # This is impossible because we should always be able to find und as a
     # parent.
-    die 'Impossible! Could not find a parent!';
+    confess 'Impossible! Could not find a parent!';
 }
 
 sub _parent_of_code ( $self, $code ) {
@@ -329,37 +351,38 @@ sub _parent_of_code ( $self, $code ) {
         if $explicit_parents->{$code};
 
     return
-          $code =~ /-/    ? $code =~ s/-[^-]+$//r
-        : $code ne 'root' ? 'root'
-        :                   die 'There is no parent for the root locale!';
+          $code =~ /-/   ? $code =~ s/-[^-]+$//r
+        : $code ne 'und' ? 'und'
+        :                  confess 'There is no parent for the und locale!';
 }
 
 sub _gregorian_file_for_code ( $self, $code ) {
-    return $self->_source_data_root->child(
+    return $self->_cldr_root->child(
         qw( cldr-dates-full main ),
         $code,
         'ca-gregorian.json'
     );
 }
 
-sub _has_parent_code ($self) {
-    return $self->code ne 'root';
-}
-
 sub _build_parent_locale ($self) {
     return unless $self->_has_parent_code;
     return ModuleGenerator::Locale->instance(
-        code             => $self->_parent_code,
-        source_data_root => $self->_source_data_root
+        code       => $self->_parent_code,
+        cldr_root  => $self->_cldr_root,
+        glibc_root => $self->_glibc_root,
     );
 }
 
+sub _has_parent_code ($self) {
+    return $self->code ne 'und';
+}
+
 sub _explicit_parents ($self) {
     state $explicit_parents;
     return $explicit_parents if $explicit_parents;
 
     my $json = $self->_json_from(
-        $self->_source_data_root->child(
+        $self->_cldr_root->child(
             qw( cldr-core supplemental parentLocales.json ))
     );
 
@@ -391,10 +414,10 @@ sub _first_day_of_week_index ($self) {
     state $first_day_of_week_index;
     return $first_day_of_week_index if $first_day_of_week_index;
 
-    my $json = $self->_json_from(
-        $self->_source_data_root->child(
-            qw( cldr-core supplemental weekData.json ))
-    );
+    my $json
+        = $self->_json_from(
+        $self->_cldr_root->child(qw( cldr-core supplemental weekData.json ))
+        );
 
     return $first_day_of_week_index
         = $json->{supplemental}{weekData}{firstDay};
@@ -447,7 +470,7 @@ sub _en_variants_data ($self) {
 
 sub _populate_en_lookup ( $self, $type ) {
     my $json = $self->_json_from(
-        $self->_source_data_root->child(
+        $self->_cldr_root->child(
             qw( cldr-localenames-full main en ), $type . '.json'
         )
     );
@@ -484,7 +507,7 @@ sub _native_lookup ( $self, $type ) {
     my $file;
     my $locale = $self;
     while ($locale) {
-        $file = $self->_source_data_root->child(
+        $file = $self->_cldr_root->child(
             qw( cldr-localenames-full main  ),
             $locale->code, $type . '.json'
         );
